"""
This directory holds language definitions.

Language definitions hold expressions that help defining specific syntax
elements for a programming language.

Currently defined keys are:

  names
  extensions
  comment delimiter
  multiline comment delimiters
  string delimiters
  multiline string delimiters
"""
